@@ -3,8 +3,8 @@ import xml.etree.ElementTree
 
 from typing import Any, List
 
-from aiojenkins.exceptions import JenkinsError, JenkinsNotFoundError
-from aiojenkins.utils import construct_node_config, parse_build_url
+from .exceptions import JenkinsError, JenkinsNotFoundError
+from .utils import construct_node_config, parse_build_url
 
 
 def _parse_rss(rss: str) -> list:
@@ -148,6 +148,19 @@ class Nodes:
             params=params,
         )
 
+    async def reconfigure(self, name: str, config: str) -> None:
+        name = self._normalize_name(name)
+
+        if name == '(master)':
+            raise JenkinsError('Cannot reconfigure master node')
+
+        await self.jenkins._request(
+            'POST',
+            '/computer/{}/config.xml'.format(name),
+            data=config,
+            headers={'Content-Type': 'text/xml'},
+        )
+
     async def delete(self, name: str) -> None:
         name = self._normalize_name(name)
         await self.jenkins._request(
